PrivilegeInfo

Struct PrivilegeInfo 

#[non_exhaustive]
pub struct PrivilegeInfo { pub name: String, pub enabled: bool, pub enabled_by_default: bool, pub removed: bool, }
Represents the status of a single Windows privilege.

Returned by enumerate_privileges to describe each privilege on the current process token, including its name and current state.

Examples

use token_privilege::enumerate_privileges;

let privileges = enumerate_privileges()?;
for priv_info in &privileges {
    println!("{}: enabled={}", priv_info.name, priv_info.enabled);
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

The privilege name (e.g., "SeDebugPrivilege").

enabled: bool

Whether the privilege is currently enabled.

enabled_by_default: bool

Whether the privilege is enabled by default.

removed: bool

Whether the privilege has been removed from the token.